@@ -19,7 +19,9 @@
 video_stats <- function(videoId = NULL, ...) {
   
   results <- data.frame()
+  pb <- prog_bar(length(videoId))
   for(i in 1:length(videoId)) {
+    pb$tick()
     temp <- analytics_request(filters = paste0("video==", videoId[i]), ...)
     
     results <- dplyr::bind_rows(results, error_checking(temp, videoId[i], "video"))
@@ -45,10 +47,13 @@ video_stats <- function(videoId = NULL, ...) {
 #' playlist_stats(playlistId = "PL2MI040U_GXq1L5JUxNOulWCyXn-7QyZK")
 #' }
 
+
 playlist_stats <- function(playlistId = NULL, ...) {
   
   results <- data.frame()
+  pb <- prog_bar(length(playlistId))
   for(i in 1:length(playlistId)) {
+    pb$tick()
     temp <- analytics_request(filters = paste0("playlist==", playlistId[i], ";isCurated==1"),
                               ...)
     
@@ -76,4 +81,4 @@ playlist_stats <- function(playlistId = NULL, ...) {
 channel_stats <- function(...) {
   temp <- analytics_request(...)
   return(temp)
-}
\ No newline at end of file
+}
